<?php

/**
 * Main helper for Montonio_Gateway
 *
 * @category    Montonio
 * @package     Montonio_Gateway
 * @author      Henrik Rank @ Montonio Finance OÜ <info@montonio.com>
 */
class Montonio_Gateway_Helper_Data extends Mage_Core_Helper_Abstract
{
    /**
     * Application URL for Production environment
     */
    const APPLICATION_URL_PRODUCTION = 'https://application.montonio.com';

    /**
    * Application URL for Sandbox environment
    */
    const APPLICATION_URL_SANDBOX = 'https://sandbox-application.montonio.com';

    /**
     * The Montonio storeConfig path
     */
    const CONFIG_PATH = 'payment/montonio';
    
    /**
     * Check that currencies match
     *
     * @param string $iso         Currency code in montonio application
     * @param string $iso_magento Currency code in Montonio
     * 
     * @return void
     * 
     * @throws Exception if currencies dont match
     */
    public function checkCurrency($iso, $iso_magento)
    {
        if ($iso != $iso_magento) {
            throw new Exception('Currencies don\'t match.');
        };
    }

    /**
     * Check that order amounts match
     *
     * @param float $loanAmount The amount in Montonio applicaiton
     * @param float $totalPaid  The order grand total
     * 
     * @return void
     * 
     * @throws Exception if order total and montonio loan amount don't match
     */
    public function checkAmount($loanAmount, $totalPaid)
    {
        if (self::_round($loanAmount) !== self::_round($totalPaid)) {
            throw new Exception('Loan amounts don\'t match.');
        }
    }

    /**
     * Simple rounding function used for product prices
     *
     * @param float $float
     * 
     * @return string The rounded float
     */
    private function _round($float)
    {
        return (string) (round($float, 2) * 100);
    }

    /**
    * Get Montonio Access Key
    * 
    * @return string
    */
    public function getAccessKey() 
    {
        return $this->_getConfigValue('access_key');
    }

    /**
    * Get Montonio Secret Key
    * 
    * @return string
    */
    public function getSecretKey() 
    {
        return $this->_getConfigValue('secret_key');
    }

    /**
    * Get Montonio Environment
    * 
    * @return string
    */
    public function getEnvironment() 
    {
        return $this->isSandbox() ? 'sandbox' : 'production';
    }

    /**
    * Get description for payment option in checkout
    * 
    * @return string
    */
    public function getDescription() 
    {
        return $this->_getConfigValue('description');
    }

    /**
    * Get title for payment option in checkout
    * 
    * @return string
    */
    public function getTitle() 
    {
        return $this->_getConfigValue('title');
    }

    /**
    * Accept payments through Montonio Sandbox API?
    * 
    * @return boolean
    */
    public function isSandbox()
    {
        return $this->_getConfigValue('sandbox') == 1;
    }

    /**
     * Get the minimum order amout to display Montonio at checkout
     *
     * @return mixed
     */
    public function getMinOrderTotal() 
    {
        return $this->_getConfigValue('min_order_total');
    }

    /**
    * Get the maximum order amout to display Montonio at checkout
    *
    * @return mixed
    */
    public function getMaxOrderTotal()
    {
        return $this->_getConfigValue('max_order_total');
    }

    /**
     * Get Montonio Application URL
     *
     * @return string 
     */
    public function getApplicationUrl()
    {
        return Mage::helper('montonio')->isSandbox() ? self::APPLICATION_URL_SANDBOX : self::APPLICATION_URL_PRODUCTION; 
    }

    /**
    * Method to retrieve config value
    * 
    * @return mixed
    */
    private function _getConfigValue($value)
    {
        $config = Mage::getStoreConfig(self::CONFIG_PATH);
        return $config[$value];
    }
}
